@@ -1,4 +1,4 @@
-/*$Id: common.js,v 1.15 2007/09/22 07:38:06 jwrobel Exp $*/
+/*$Id: common.js,v 1.16 2008/06/01 12:21:01 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -64,6 +64,18 @@ function changeFirekeeperState(state, msg) {
 /*Get (or create) global services.*/
 function getServices()
 {
+	var prefs = Components.classes["@mozilla.org/preferences-service;1"].
+		getService(Components.interfaces.nsIPrefService);
+	prefs = prefs.getBranch("browser.cache.memory.");
+	if (!prefs.getBoolPref("enable")) {
+		var errMsg = "Firekeeper load failed: " + 
+			"Browser memory cache needs to be enabled. " +
+			"You can change this setting in about:config."
+		changeFirekeeperState("error", errMsg);
+		throw(errMsg);
+	}
+		
+	
 	firekeeper  = Components.classes[FIREKEEPER_CONTRACTID];
 	if (firekeeper == null){
 		var errMsg = "Firekeeper load failed: " + 
