@@ -1,4 +1,4 @@
-/*$Id: firekeeper.js,v 1.18 2007/09/09 10:44:26 jwrobel Exp $*/
+/*$Id: firekeeper.js,v 1.20 2008/06/01 15:38:20 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -48,16 +48,16 @@ var enabledObserver =
 
 	setStatus: function()
 	{
-		var menuitem = document.getElementById('enable-menuitem');
+		//var menuitem = document.getElementById('enable-menuitem');
 		var statusbar = document.getElementById('firekeeper-status');		
 		var enable = this.branch.getBoolPref("enabled");
 		
 		if (enable){
-			menuitem.setAttribute('label', 'Disable Firekeeper');
+			//menuitem.setAttribute('label', 'Disable Firekeeper');
 			statusbar.setAttribute('status', 'enabled');
 		}
 		else{
-			menuitem.setAttribute('label', 'Enable Firekeeper');
+			//menuitem.setAttribute('label', 'Enable Firekeeper');
 			statusbar.setAttribute('status', 'disabled');
 		}		
 	},
@@ -115,7 +115,7 @@ function openConfigWindow()
 	//window.openDialog('chrome://firekeeper/content/config.xul', 'preferences', 
 	//	  'chrome,resizable,centerscreen,dialog=no');
 	window.openDialog('chrome://firekeeper/content/config.xul', '_blank', 
-		    'chrome,modal=yes,resizable,centerscreen');
+			  'chrome,modal=yes,resizable,centerscreen');
 	
 }
 
