@@ -1,4 +1,4 @@
-/*$Id: fkRuleReference.cpp,v 1.6 2007/09/17 22:18:56 jwrobel Exp $*/
+/*$Id: fkRuleReference.cpp,v 1.7 2008/05/18 10:29:01 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -19,8 +19,8 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  * ***** END LICENSE BLOCK ***** */
 
+#include "plstr.h"
 #include "nsMemory.h"
-#include "nsCRT.h"
 #include "fkRuleReference.h"
 #include "Error.h"
 
@@ -40,13 +40,13 @@ fkRuleReference::Init(const reference *ref)
 		return NS_ERROR_NULL_POINTER;
 	
 	if (ref->system){
-		system = nsCRT::strdup(ref->system);	
+		system = PL_strdup(ref->system);	
 		if (!system)
 			return NS_ERROR_OUT_OF_MEMORY;
 	}
 
 	if (ref->refId){
-		refId = nsCRT::strdup(ref->refId);	
+		refId = PL_strdup(ref->refId);	
 		if (!refId)
 			return NS_ERROR_OUT_OF_MEMORY;		
 	}
@@ -72,7 +72,7 @@ NS_IMETHODIMP fkRuleReference::GetSystem(char **aSystem)
 	*aSystem = nsnull;
 
 	if(system){
-		*aSystem = nsCRT::strdup(system);	
+		*aSystem = PL_strdup(system);	
 		if (!*aSystem)
 			return NS_ERROR_OUT_OF_MEMORY;
 	}
@@ -88,7 +88,7 @@ NS_IMETHODIMP fkRuleReference::GetRefId(char **aRefId)
 	*aRefId = nsnull;
 
 	if(refId){
-		*aRefId = nsCRT::strdup(refId);	
+		*aRefId = PL_strdup(refId);	
 		if (!*aRefId)
 			return NS_ERROR_OUT_OF_MEMORY;
 	}
