@@ -57,6 +57,9 @@ echo "
 	      <updateLink>
 		http://downloads.mozdev.org/firekeeper/$INSTALL_FILE
 	      </updateLink>
+              <updateHash>
+                sha1:
+              </updateHash>
 	    </RDF:Description>
 	  </targetApplication>
 	</RDF:Description>
